/****************************************************************************
** Meta object code from reading C++ file 'ktron.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ksnakeduel-26.04.3/src/ktron.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ktron.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5KTronE_t {};
} // unnamed namespace

template <> constexpr inline auto KTron::qt_create_metaobjectdata<qt_meta_tag_ZN5KTronE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTron",
        "close",
        "",
        "loadSettings",
        "changeStatus",
        "updateScore",
        "showSettings",
        "showHighscores",
        "optionsConfigureKeys",
        "blockPause",
        "block",
        "triggerKey0Up",
        "triggerKey0Down",
        "triggerKey0Left",
        "triggerKey0Right",
        "triggerKey0Accelerate",
        "triggerKey1Up",
        "triggerKey1Down",
        "triggerKey1Left",
        "triggerKey1Right",
        "triggerKey1Accelerate"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'close'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadSettings'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeStatus'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateScore'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showSettings'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showHighscores'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'optionsConfigureKeys'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'blockPause'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'triggerKey0Up'
        QtMocHelpers::SlotData<void(bool)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'triggerKey0Down'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'triggerKey0Left'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'triggerKey0Right'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'triggerKey0Accelerate'
        QtMocHelpers::SlotData<void(bool)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'triggerKey1Up'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'triggerKey1Down'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'triggerKey1Left'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'triggerKey1Right'
        QtMocHelpers::SlotData<void(bool)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'triggerKey1Accelerate'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KTron, qt_meta_tag_ZN5KTronE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTron::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KTronE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KTronE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5KTronE_t>.metaTypes,
    nullptr
} };

void KTron::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KTron *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->close(); break;
        case 1: _t->loadSettings(); break;
        case 2: _t->changeStatus(); break;
        case 3: _t->updateScore(); break;
        case 4: _t->showSettings(); break;
        case 5: _t->showHighscores(); break;
        case 6: _t->optionsConfigureKeys(); break;
        case 7: _t->blockPause((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->triggerKey0Up((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->triggerKey0Down((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->triggerKey0Left((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->triggerKey0Right((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->triggerKey0Accelerate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->triggerKey1Up((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->triggerKey1Down((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->triggerKey1Left((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->triggerKey1Right((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->triggerKey1Accelerate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *KTron::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTron::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KTronE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KTron::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}
QT_WARNING_POP
