/********************************************************************************
** Form generated from reading UI file 'general.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERAL_H
#define UI_GENERAL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_General
{
public:
    QVBoxLayout *vboxLayout;
    QFrame *generalFrame;
    QVBoxLayout *vboxLayout1;
    QGroupBox *gameTypeGroup;
    QGridLayout *gridLayout;
    KComboBox *kcfg_GameType;
    QLabel *gameTypeLabel;
    QGroupBox *behaviorGroup;
    QVBoxLayout *vboxLayout2;
    QCheckBox *kcfg_AcceleratorBlocked;
    QGroupBox *playerNamesGroup;
    QGridLayout *gridLayout1;
    KLineEdit *kcfg_NamePlayer1;
    KLineEdit *kcfg_NamePlayer2;
    QLabel *namePlayer1Label;
    QLabel *namePlayer2Label;
    QGroupBox *gameOptionsGroup;
    QGridLayout *gridLayout2;
    QLabel *roundsLabel;
    QSpinBox *kcfg_Rounds;

    void setupUi(QWidget *General)
    {
        if (General->objectName().isEmpty())
            General->setObjectName("General");
        General->resize(400, 379);
        vboxLayout = new QVBoxLayout(General);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName("vboxLayout");
        generalFrame = new QFrame(General);
        generalFrame->setObjectName("generalFrame");
        generalFrame->setFrameShape(QFrame::StyledPanel);
        generalFrame->setFrameShadow(QFrame::Plain);
        generalFrame->setLineWidth(0);
        vboxLayout1 = new QVBoxLayout(generalFrame);
        vboxLayout1->setObjectName("vboxLayout1");
        gameTypeGroup = new QGroupBox(generalFrame);
        gameTypeGroup->setObjectName("gameTypeGroup");
        gridLayout = new QGridLayout(gameTypeGroup);
        gridLayout->setObjectName("gridLayout");
        kcfg_GameType = new KComboBox(gameTypeGroup);
        kcfg_GameType->addItem(QString());
        kcfg_GameType->addItem(QString());
        kcfg_GameType->addItem(QString());
        kcfg_GameType->setObjectName("kcfg_GameType");

        gridLayout->addWidget(kcfg_GameType, 0, 1, 1, 1);

        gameTypeLabel = new QLabel(gameTypeGroup);
        gameTypeLabel->setObjectName("gameTypeLabel");
        gameTypeLabel->setWordWrap(false);

        gridLayout->addWidget(gameTypeLabel, 0, 0, 1, 1);


        vboxLayout1->addWidget(gameTypeGroup);

        behaviorGroup = new QGroupBox(generalFrame);
        behaviorGroup->setObjectName("behaviorGroup");
        vboxLayout2 = new QVBoxLayout(behaviorGroup);
        vboxLayout2->setObjectName("vboxLayout2");
        kcfg_AcceleratorBlocked = new QCheckBox(behaviorGroup);
        kcfg_AcceleratorBlocked->setObjectName("kcfg_AcceleratorBlocked");

        vboxLayout2->addWidget(kcfg_AcceleratorBlocked);


        vboxLayout1->addWidget(behaviorGroup);

        playerNamesGroup = new QGroupBox(generalFrame);
        playerNamesGroup->setObjectName("playerNamesGroup");
        gridLayout1 = new QGridLayout(playerNamesGroup);
        gridLayout1->setObjectName("gridLayout1");
        kcfg_NamePlayer1 = new KLineEdit(playerNamesGroup);
        kcfg_NamePlayer1->setObjectName("kcfg_NamePlayer1");

        gridLayout1->addWidget(kcfg_NamePlayer1, 0, 1, 1, 1);

        kcfg_NamePlayer2 = new KLineEdit(playerNamesGroup);
        kcfg_NamePlayer2->setObjectName("kcfg_NamePlayer2");

        gridLayout1->addWidget(kcfg_NamePlayer2, 1, 1, 1, 1);

        namePlayer1Label = new QLabel(playerNamesGroup);
        namePlayer1Label->setObjectName("namePlayer1Label");
        namePlayer1Label->setWordWrap(false);

        gridLayout1->addWidget(namePlayer1Label, 0, 0, 1, 1);

        namePlayer2Label = new QLabel(playerNamesGroup);
        namePlayer2Label->setObjectName("namePlayer2Label");
        namePlayer2Label->setWordWrap(false);

        gridLayout1->addWidget(namePlayer2Label, 1, 0, 1, 1);


        vboxLayout1->addWidget(playerNamesGroup);

        gameOptionsGroup = new QGroupBox(generalFrame);
        gameOptionsGroup->setObjectName("gameOptionsGroup");
        gridLayout2 = new QGridLayout(gameOptionsGroup);
        gridLayout2->setObjectName("gridLayout2");
        roundsLabel = new QLabel(gameOptionsGroup);
        roundsLabel->setObjectName("roundsLabel");
        roundsLabel->setWordWrap(false);

        gridLayout2->addWidget(roundsLabel, 0, 0, 1, 1);

        kcfg_Rounds = new QSpinBox(gameOptionsGroup);
        kcfg_Rounds->setObjectName("kcfg_Rounds");
        kcfg_Rounds->setMinimum(2);
        kcfg_Rounds->setValue(5);

        gridLayout2->addWidget(kcfg_Rounds, 0, 1, 1, 1);


        vboxLayout1->addWidget(gameOptionsGroup);


        vboxLayout->addWidget(generalFrame);


        retranslateUi(General);

        QMetaObject::connectSlotsByName(General);
    } // setupUi

    void retranslateUi(QWidget *General)
    {
        gameTypeGroup->setTitle(tr2i18n("Game Type", nullptr));
        kcfg_GameType->setItemText(0, tr2i18n("KSnakeDuel: Player vs Computer", nullptr));
        kcfg_GameType->setItemText(1, tr2i18n("KSnakeDuel: Player vs Player", nullptr));
        kcfg_GameType->setItemText(2, tr2i18n("KSnake mode: Single player", nullptr));

        gameTypeLabel->setText(tr2i18n("Game type:", nullptr));
        behaviorGroup->setTitle(tr2i18n("Behavior", nullptr));
        kcfg_AcceleratorBlocked->setText(tr2i18n("&Disable acceleration", nullptr));
        playerNamesGroup->setTitle(tr2i18n("Player Names", nullptr));
        namePlayer1Label->setText(tr2i18n("Right player / KSnake mode:", nullptr));
        namePlayer2Label->setText(tr2i18n("Left player:", nullptr));
        gameOptionsGroup->setTitle(tr2i18n("Game Options", nullptr));
        roundsLabel->setText(tr2i18n("Rounds to win:", nullptr));
        (void)General;
    } // retranslateUi

};

namespace Ui {
    class General: public Ui_General {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERAL_H

